# vs-deband, a collection of wrappers and functions for debanding

For support you can check out the [JET Discord server](https://discord.gg/XTpc6Fa9eB). <br><br>

## How to install

Install `vsdeband` with the following command:

```sh
pip install vsdeband
```

Or if you want the latest git version, install it with this command:

```sh
pip install git+https://github.com/Jaded-Encoding-Thaumaturgy/vs-deband.git
```

<br>
